You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@whimsical.apache.org by cu...@apache.org on 2017/07/04 01:23:56 UTC

[whimsy] branch master updated: Fix title and missed breadcrumbs->nav

This is an automated email from the ASF dual-hosted git repository.

curcuru pushed a commit to branch master
in repository https://gitbox.apache.org/repos/asf/whimsy.git


The following commit(s) were added to refs/heads/master by this push:
     new e2e13f2  Fix title and missed breadcrumbs->nav
e2e13f2 is described below

commit e2e13f2675ca6df37da3e455f7753a9711e6bec1
Author: Shane Curcuru <as...@shanecurcuru.org>
AuthorDate: Mon Jul 3 21:23:51 2017 -0400

    Fix title and missed breadcrumbs->nav
---
 www/roster/views/ppmc/main.js.rb | 23 ++++++++++++++---------
 www/roster/views/ppmcs.html.rb   |  8 +-------
 2 files changed, 15 insertions(+), 16 deletions(-)

diff --git a/www/roster/views/ppmcs.html.rb b/www/roster/views/ppmcs.html.rb
index 477c1cc..35bc6ce 100644
--- a/www/roster/views/ppmcs.html.rb
+++ b/www/roster/views/ppmcs.html.rb
@@ -4,16 +4,10 @@
 
 _html do
   _base href: '..'
-  _title 
   _link rel: 'stylesheet', href: 'stylesheets/app.css'
-
-  _banner breadcrumbs: {
-    roster: '.',
-    ppmc: 'ppmc/'
-  }
   _body? do
     _whimsy_body(
-      title: 'ASF Podling PMC Roster',
+      title: 'ASF Podling List',
       breadcrumbs: {
         roster: '.',
         ppmc: 'ppmc/'

diff --git a/www/roster/views/ppmc/main.js.rb b/www/roster/views/ppmc/main.js.rb
index ca95147..e626c91 100644
--- a/www/roster/views/ppmc/main.js.rb
+++ b/www/roster/views/ppmc/main.js.rb
@@ -13,15 +13,20 @@ class PPMC < React
       @@auth.ipmc ||= @@auth.member
     end
 
-    # add jump links to main sections of page
-    _div.breadcrumbs do
-      _a 'PPMC', :href => "ppmc/#{@ppmc.id}#ppmc"
-      _span " \u00BB "
-      _a 'Mail Moderators', :href => "ppmc/#{@ppmc.id}#mail"
-      _span " \u00BB "
-      _a 'Reporting Schedule', :href => "ppmc/#{@ppmc.id}#reporting"
-      _span " \u00BB "
-      _a 'Status', :href => "ppmc/#{@ppmc.id}#podlingStatus"
+    # add jump links to main sections of page using Bootstrap nav element
+    _ul.nav.nav_pills do
+      _li role: "presentation" do
+        _a 'PPMC', :href => "ppmc/#{@ppmc.id}#ppmc"
+      end
+      _li role: "presentation" do
+        _a 'Mail Moderators', :href => "ppmc/#{@ppmc.id}#mail"
+      end
+      _li role: "presentation" do
+        _a 'Reporting Schedule', :href => "ppmc/#{@ppmc.id}#reporting"
+      end
+      _li role: "presentation" do
+        _a 'Status', :href => "ppmc/#{@ppmc.id}#podlingStatus"
+      end
     end
 
     # header
-- 
To stop receiving notification emails like this one, please contact
['"commits@whimsical.apache.org" <co...@whimsical.apache.org>'].